The objeective of this package is to learn more
about how to handle the creation o packages in python.

-- Notes for future package creation



-- FOLDER(PACKAGE NAME)
  -- setup.py
  -- README.md
     --FOLDER(WITH PACKAGE NAME INSIDE THE SETUP.PY)
        -- __init__.py 
        -- module.py

    